===============
Release History
===============

v0.0.1dev1 (development release)
--------------------------------

Contains a basic functionality to run multiple ATSAS simulations in parallel
using Dask local cluster.
